@@ -83,8 +83,11 @@ def cliques_by_dim(g, max_dim=None) -> Cliques:
     sorted_cliques = sorted(oriented_cliques, key=len)
     clqs = Cliques(total_count=len(cliques))
     for dim, cs in groupby(sorted_cliques, key=len):
-        if dim == 2:
-            cs = sorted(cs, key=sum)
+        if dim == 1:
+            cs = sorted(cs, key=lambda c: c[0])
+            clqs.append([Clique(c) for c in cs])
+        elif dim == 2:
+            cs = sorted(cs, key=lambda c: g.get_eid(c[0], c[1]))
             clqs.append([Clique(c, np.sqrt(g[c[0],c[1]])) for c in cs])
         else:
             cs = sorted(cs, key=sum)
